# Release Checklist

Pre-release
1. Tests pass
2. CI passes
3. Build succeeds
4. Clean install succeeds
5. Documentation is up to date
6. Changelog is up to date
7. Tag and release on GitHub
8. Release is published to PyPI
9. Update dockerfile
10. Update .env.example (if necessary)

Post-release
- Clean install from PyPi works


## v0.3.8 - 2025-03-07

Pre-release
1. Tests pass - [X]
2. CI passes - [X]
3. Build succeeds - [X]
4. Documentation is up to date - [X]
5. Changelog is up to date - [X]
6. Tag and release on GitHub
7. Release is published to PyPI
8. Update dockerfile - [X]
9. Update .env.example (if necessary) - [X]

Post-release
10. Clean install from PyPi works - [X]



## v0.3.0 - 2025-02-22

1. Tests pass - [X]
2. CI passes - [X]
3. Build succeeds - [X]
4. Clean install succeeds - [X]
5. Documentation is up to date - [X]
6. Changelog is up to date - [X]
7. Tag and release on GitHub - [X]
8. Release is published to PyPI - [X]
9. Clean install from PyPI works - [X]
